@@ -1,9 +1,13 @@
-from typing import Any, Dict, List, Optional, Tuple, Type
+from typing import Any, Dict, List, Tuple, Type
 
 import duckdb
+from sqlalchemy import types as sqltypes
+from sqlalchemy import util
 from sqlalchemy.dialects.postgresql import dialect as postgres_dialect
 from sqlalchemy.dialects.postgresql.base import PGExecutionContext, PGInspector
-from sqlalchemy.engine import URL
+from sqlalchemy.engine.url import URL
+
+name = "duckdb"
 
 
 class DBAPI:
@@ -59,24 +63,8 @@ class ConnectionWrapper:
         pass
 
     @property
-    def description(
-        self,
-    ) -> Optional[
-        # TODO: remove this override once the next version of duckdb is released
-        Tuple[
-            str,
-            str,
-            Optional[str],
-            Optional[str],
-            Optional[str],
-            Optional[str],
-            Optional[str],
-        ]
-    ]:
-        try:
-            return self.c.description
-        except RuntimeError:
-            return None
+    def rowcount(self) -> int:
+        return -1
 
     def executemany(
         self, statement: str, parameters: List[Dict] = None, context: Any = None
@@ -84,16 +72,27 @@ class ConnectionWrapper:
         self.c.executemany(statement, parameters)
 
     def execute(
-        self, statement: str, parameters: Dict = None, context: Any = None
+        self, statement: str, parameters: Tuple = None, context: Any = None
     ) -> None:
         try:
-            if parameters is None:
+            if statement.lower() == "commit":  # this is largely for ipython-sql
+                self.c.commit()
+            elif statement.lower() == "register":
+                assert parameters and len(parameters) == 2, parameters
+                view_name, df = parameters
+                self.c.register(view_name, df)
+            elif parameters is None:
                 self.c.execute(statement)
             else:
                 self.c.execute(statement, parameters)
         except RuntimeError as e:
             if e.args[0].startswith("Not implemented Error"):
                 raise NotImplementedError(*e.args) from e
+            elif (
+                e.args[0]
+                == "TransactionContext Error: cannot commit - no transaction is active"
+            ):
+                return
             else:
                 raise e
 
@@ -101,10 +100,20 @@ class ConnectionWrapper:
 class Dialect(postgres_dialect):
     _has_events = False
     identifier_preparer = None
-    default_schema_name = "main"
-    server_version_info = (8, 0)
     inspector = DuckDBInspector
     # colspecs TODO: remap types to duckdb types
+    colspecs = util.update_copy(
+        postgres_dialect.colspecs,
+        {
+            # the psycopg2 driver registers a _PGNumeric with custom logic for
+            # postgres type_codes (such as 701 for float) that duckdb doesn't have
+            sqltypes.Numeric: sqltypes.Numeric,
+        },
+    )
+
+    def __init__(self, *args: Any, **kwargs: Any) -> None:
+        kwargs["use_native_hstore"] = False
+        super().__init__(*args, **kwargs)
 
     def connect(self, *args: Any, **kwargs: Any) -> ConnectionWrapper:
         return ConnectionWrapper(duckdb.connect(*args, **kwargs))
@@ -144,13 +153,28 @@ class Dialect(postgres_dialect):
         return DBAPI
 
     def create_connect_args(self, u: URL) -> Tuple[Tuple, Dict]:
-        return (), {"database": u.render_as_string(hide_password=False).split("///")[1]}
+        return (), {"database": u.__to_string__(hide_password=False).split("///")[1]}
 
-    def initialize(self, connection: ConnectionWrapper) -> None:
-        pass
+    def _get_server_version_info(
+        self, connection: ConnectionWrapper
+    ) -> Tuple[int, int]:
+        return (8, 0)
+
+    def get_default_isolation_level(self, connection: ConnectionWrapper) -> None:
+        raise NotImplementedError()
 
     def do_rollback(self, connection: ConnectionWrapper) -> None:
-        pass
+        try:
+            super().do_rollback(connection)
+        except RuntimeError as e:
+            if (
+                e.args[0]
+                != "TransactionContext Error: cannot rollback - no transaction is active"
+            ):
+                raise e
+
+    def do_begin(self, connection: ConnectionWrapper) -> None:
+        connection.execute("begin")
 
     @classmethod
     def get_dialect_cls(cls, u: str) -> Type["Dialect"]:
