@@ -1,4 +1,6 @@
-from hypothesis import assume, given
+from datetime import timedelta
+
+from hypothesis import assume, given, settings
 from hypothesis.strategies import text
 from pytest import fixture, mark
 from sqlalchemy import (
@@ -76,6 +78,7 @@ def test_foreign(session: Session) -> None:
 
 
 @given(text())
+@settings(deadline=timedelta(seconds=1))
 def test_simple_string(s: str) -> None:
     assume("\x00" not in s)
     eng = create_engine("duckdb:///:memory:")
@@ -91,8 +94,8 @@ def test_simple_string(s: str) -> None:
     assert owner.owned.name == s
 
 
-def test_get_tables(engine: Engine) -> None:
-    assert engine.table_names()
+def test_get_tables(inspector: PGInspector) -> None:
+    assert inspector.get_table_names()
 
 
 @fixture
@@ -119,7 +122,6 @@ def test_get_check_constraints(inspector: PGInspector) -> None:
     inspector.get_check_constraints("test", None)
 
 
-@mark.xfail(reason="reflection not yet supported in duckdb", raises=NotImplementedError)
 def test_get_unique_constraints(inspector: PGInspector) -> None:
     inspector.get_unique_constraints("test", None)
 
@@ -132,6 +134,17 @@ def test_reflect(session: Session, engine: Engine) -> None:
     meta.reflect(only=["test"])
 
 
+def test_commit(session: Session, engine: Engine) -> None:
+    session.execute("commit;")
+
+    from IPython.core.interactiveshell import InteractiveShell
+
+    shell = InteractiveShell()
+    assert not shell.run_line_magic("load_ext", "sql")
+    assert not shell.run_line_magic("sql", "duckdb:///:memory:")
+    assert shell.run_line_magic("sql", "select 42;") == [(42,)]
+
+
 def test_table_reflect(session: Session, engine: Engine) -> None:
     session.execute("create table test (id int);")
     session.commit()
@@ -143,16 +156,12 @@ def test_table_reflect(session: Session, engine: Engine) -> None:
     insp.reflect_table(user_table, None)
 
 
-@mark.xfail(reason="current duckdb release doesnt support size param", raises=TypeError)
 def test_fetch_df_chunks() -> None:
     import duckdb
 
     duckdb.connect(":memory:").execute("select 1").fetch_df_chunk(1)
 
 
-@mark.xfail(
-    reason="current duckdb release doesnt support size param", raises=RuntimeError
-)
 def test_description() -> None:
     import duckdb
 
